@@ -19,7 +19,11 @@
 import os
 import shutil
 import tempfile
-import unittest
+import sys
+if sys.version_info[:2] <= (2, 6):
+	import unittest2 as unittest
+else:
+	import unittest
 
 #**********************************************************************************************************************
 #***	Internal imports.
